Documentation
¶
Index ¶
- type App
- func (a *App) Close(ctx context.Context, number string, opts CloseOptions) error
- func (a *App) Diff(ctx context.Context, number string, opts DiffOptions) error
- func (a *App) DiffAll(ctx context.Context, opts DiffOptions) error
- func (a *App) Edit(ctx context.Context, number string) error
- func (a *App) Init(ctx context.Context, owner, repo string) error
- func (a *App) List(ctx context.Context, opts ListOptions) error
- func (a *App) NewIssue(ctx context.Context, title string, opts NewOptions) error
- func (a *App) Pull(ctx context.Context, opts PullOptions, args []string) error
- func (a *App) Push(ctx context.Context, opts PushOptions, args []string) error
- func (a *App) Reopen(ctx context.Context, number string) error
- func (a *App) Status(ctx context.Context) error
- func (a *App) View(ctx context.Context, ref string, opts ViewOptions) error
- type CloseOptions
- type DiffOptions
- type IssueFile
- type IssueTypeCache
- type IssueTypeEntry
- type LabelCache
- type LabelEntry
- type ListOptions
- type LoadResult
- type MilestoneCache
- type MilestoneEntry
- type NewOptions
- type ParseError
- type PendingComment
- type ProjectCache
- type ProjectEntry
- type PullOptions
- type PushOptions
- type ViewOptions
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type App ¶
type App struct {
Root string
Runner ghcli.Runner
Now func() time.Time
Out io.Writer
Err io.Writer
Theme *theme.Theme
}
type CloseOptions ¶
type CloseOptions struct {
Reason string
}
type DiffOptions ¶
type DiffOptions struct {
Remote bool
}
type IssueTypeCache ¶
type IssueTypeCache struct {
IssueTypes []IssueTypeEntry `json:"issue_types"`
SyncedAt time.Time `json:"synced_at"`
}
IssueTypeCache stores the synced issue types from GitHub
type IssueTypeEntry ¶
type IssueTypeEntry struct {
ID string `json:"id"`
Name string `json:"name"`
Description string `json:"description,omitempty"`
}
IssueTypeEntry represents a single issue type
type LabelCache ¶
type LabelCache struct {
Labels []LabelEntry `json:"labels"`
SyncedAt time.Time `json:"synced_at"`
}
LabelCache stores the synced labels from GitHub
type LabelEntry ¶
LabelEntry represents a single label with its color
type ListOptions ¶
type LoadResult ¶
type LoadResult struct {
Issues []IssueFile
Errors []ParseError
}
LoadResult contains loaded issues and any parse errors encountered
type MilestoneCache ¶
type MilestoneCache struct {
Milestones []MilestoneEntry `json:"milestones"`
SyncedAt time.Time `json:"synced_at"`
}
MilestoneCache stores the synced milestones from GitHub
type MilestoneEntry ¶
type MilestoneEntry struct {
Title string `json:"title"`
Description string `json:"description,omitempty"`
DueOn *string `json:"due_on,omitempty"`
State string `json:"state"`
}
MilestoneEntry represents a single milestone
type NewOptions ¶
type ParseError ¶
ParseError represents an error parsing a specific issue file
func (ParseError) Error ¶
func (e ParseError) Error() string
type PendingComment ¶
type PendingComment struct {
IssueNumber issue.IssueNumber
Body string
Path string
}
PendingComment represents a pending comment for an issue
type ProjectCache ¶
type ProjectCache struct {
Projects []ProjectEntry `json:"projects"`
SyncedAt time.Time `json:"synced_at"`
}
ProjectCache stores the synced projects from GitHub
type ProjectEntry ¶
ProjectEntry represents a single project
type PullOptions ¶
type PushOptions ¶
type ViewOptions ¶
type ViewOptions struct {
Raw bool
}
Click to show internal directories.
Click to hide internal directories.